@@ -18,8 +18,10 @@ cfg_if! {
     } else if #[cfg(target_os = "macos")] {
         mod unix;
         pub(crate) use self::unix::*;
+    } else {
+        mod other;
+        pub(crate) use self::other::*;
     }
-    // TODO: Add dummy impls here for other OSes?
 }
 
 #[derive(Debug, Clone, Default)]
@@ -46,7 +48,7 @@ pub struct IoData {
 pub type IoHarvest = HashMap<String, Option<IoData>>;
 
 cfg_if! {
-    if #[cfg(not(target_os = "freebsd"))] {
+    if #[cfg(any(target_os = "linux", target_os = "macos", target_os = "windows"))] {
         mod io_counters;
         pub use io_counters::IoCounters;
 
@@ -68,6 +70,10 @@ cfg_if! {
 
             Ok(io_hash)
         }
+    } else if #[cfg(not(target_os = "freebsd"))] {
+        pub fn get_io_usage() -> anyhow::Result<IoHarvest> {
+            anyhow::bail!("Unsupported OS");
+        }
     }
 }
 
