@@ -1,15 +1,17 @@
 //! Process data collection for Linux.
 
-use std::fs::File;
+mod process;
+use process::*;
+
+use std::fs::{self, File};
 use std::io::{BufRead, BufReader};
 use std::time::Duration;
 
-use hashbrown::{HashMap, HashSet};
-use procfs::process::{Process, Stat};
-use sysinfo::{ProcessStatus, System};
+use hashbrown::HashSet;
+use sysinfo::ProcessStatus;
 
 use super::{ProcessHarvest, UserTable};
-use crate::components::tui_widget::time_chart::Point;
+use crate::app::data_harvester::DataCollector;
 use crate::utils::error::{self, BottomError};
 use crate::Pid;
 
@@ -24,8 +26,11 @@ pub struct PrevProcDetails {
     cpu_time: u64,
 }
 
-fn calculate_idle_values(line: &str) -> Point {
-    /// Converts a `Option<&str>` value to an f64. If it fails to parse or is `None`, then it will return `0_f64`.
+/// Given `/proc/stat` file contents, determine the idle and non-idle values of the CPU
+/// used to calculate CPU usage.
+fn fetch_cpu_usage(line: &str) -> (f64, f64) {
+    /// Converts a `Option<&str>` value to an f64. If it fails to parse or is `None`, it
+    /// will return `0_f64`.
     fn str_to_f64(val: Option<&str>) -> f64 {
         val.and_then(|v| v.parse::<f64>().ok()).unwrap_or(0_f64)
     }
@@ -42,7 +47,6 @@ fn calculate_idle_values(line: &str) -> Point {
 
     // Note we do not get guest/guest_nice, as they are calculated as part of user/nice respectively
     // See https://github.com/htop-dev/htop/blob/main/linux/LinuxProcessList.c
-
     let idle = idle + iowait;
     let non_idle = user + nice + system + irq + softirq + steal;
 
@@ -60,11 +64,16 @@ struct CpuUsage {
 fn cpu_usage_calculation(prev_idle: &mut f64, prev_non_idle: &mut f64) -> error::Result<CpuUsage> {
     let (idle, non_idle) = {
         // From SO answer: https://stackoverflow.com/a/23376195
-        let mut reader = BufReader::new(File::open("/proc/stat")?);
-        let mut first_line = String::new();
-        reader.read_line(&mut first_line)?;
+        let first_line = {
+            // We just need a single line from this file. Read it and return it.
+            let mut reader = BufReader::new(File::open("/proc/stat")?);
+            let mut buffer = String::new();
+            reader.read_line(&mut buffer)?;
 
-        calculate_idle_values(&first_line)
+            buffer
+        };
+
+        fetch_cpu_usage(&first_line)
     };
 
     let total = idle + non_idle;
@@ -116,14 +125,21 @@ fn get_linux_cpu_usage(
 }
 
 fn read_proc(
-    prev_proc: &PrevProcDetails, process: &Process, cpu_usage: f64, cpu_fraction: f64,
+    prev_proc: &PrevProcDetails, process: Process, cpu_usage: f64, cpu_fraction: f64,
     use_current_cpu_total: bool, time_difference_in_secs: u64, total_memory: u64,
     user_table: &mut UserTable,
 ) -> error::Result<(ProcessHarvest, u64)> {
-    let stat = process.stat()?;
+    let Process {
+        pid: _,
+        uid,
+        stat,
+        io,
+        cmdline,
+    } = process;
+
     let (command, name) = {
         let truncated_name = stat.comm.as_str();
-        if let Ok(cmdline) = process.cmdline() {
+        if let Ok(cmdline) = cmdline {
             if cmdline.is_empty() {
                 (format!("[{}]", truncated_name), truncated_name.to_string())
             } else {
@@ -169,7 +185,7 @@ fn read_proc(
 
     // This can fail if permission is denied!
     let (total_read_bytes, total_write_bytes, read_bytes_per_sec, write_bytes_per_sec) =
-        if let Ok(io) = process.io() {
+        if let Ok(io) = io {
             let total_read_bytes = io.read_bytes;
             let total_write_bytes = io.write_bytes;
             let prev_total_read_bytes = prev_proc.total_read_bytes;
@@ -195,9 +211,16 @@ fn read_proc(
             (0, 0, 0, 0)
         };
 
-    let uid = process.uid()?;
+    let user = uid
+        .and_then(|uid| {
+            user_table
+                .get_uid_to_username_mapping(uid)
+                .map(Into::into)
+                .ok()
+        })
+        .unwrap_or_else(|| "N/A".into());
 
-    let time = if let Ok(ticks_per_sec) = u32::try_from(procfs::ticks_per_second()) {
+    let time = if let Ok(ticks_per_sec) = u32::try_from(rustix::param::clock_ticks_per_second()) {
         if ticks_per_sec == 0 {
             Duration::ZERO
         } else {
@@ -221,11 +244,8 @@ fn read_proc(
             total_read_bytes,
             total_write_bytes,
             process_state,
-            uid: Some(uid),
-            user: user_table
-                .get_uid_to_username_mapping(uid)
-                .map(Into::into)
-                .unwrap_or_else(|_| "N/A".into()),
+            uid,
+            user,
             time,
         },
         new_process_times,
@@ -242,11 +262,25 @@ pub(crate) struct ProcHarvestOptions {
     pub unnormalized_cpu: bool,
 }
 
-pub(crate) fn get_process_data(
-    sys: &System, prev_proc: PrevProc<'_>, pid_mapping: &mut HashMap<Pid, PrevProcDetails>,
-    proc_harvest_options: ProcHarvestOptions, time_difference_in_secs: u64, total_memory: u64,
-    user_table: &mut UserTable,
-) -> crate::utils::error::Result<Vec<ProcessHarvest>> {
+fn is_str_numeric(s: &str) -> bool {
+    s.chars().all(|c| c.is_ascii_digit())
+}
+
+pub(crate) fn linux_process_data(
+    collector: &mut DataCollector, time_difference_in_secs: u64,
+) -> error::Result<Vec<ProcessHarvest>> {
+    let total_memory = collector.total_memory();
+    let prev_proc = PrevProc {
+        prev_idle: &mut collector.prev_idle,
+        prev_non_idle: &mut collector.prev_non_idle,
+    };
+    let proc_harvest_options = ProcHarvestOptions {
+        use_current_cpu_total: collector.use_current_cpu_total,
+        unnormalized_cpu: collector.unnormalized_cpu,
+    };
+    let pid_mapping = &mut collector.pid_mapping;
+    let user_table = &mut collector.user_table;
+
     let ProcHarvestOptions {
         use_current_cpu_total,
         unnormalized_cpu,
@@ -266,7 +300,7 @@ pub(crate) fn get_process_data(
     {
         if unnormalized_cpu {
             use sysinfo::SystemExt;
-            let num_processors = sys.cpus().len() as f64;
+            let num_processors = collector.sys.cpus().len() as f64;
 
             // Note we *divide* here because the later calculation divides `cpu_usage` - in effect,
             // multiplying over the number of cores.
@@ -275,32 +309,36 @@ pub(crate) fn get_process_data(
 
         let mut pids_to_clear: HashSet<Pid> = pid_mapping.keys().cloned().collect();
 
-        let process_vector: Vec<ProcessHarvest> = std::fs::read_dir("/proc")?
-            .filter_map(|dir| {
-                if let Ok(dir) = dir {
-                    if let Ok(pid) = dir.file_name().to_string_lossy().trim().parse::<Pid>() {
-                        let Ok(process) = Process::new(pid) else {
-                            return None;
-                        };
-                        let prev_proc_details = pid_mapping.entry(pid).or_default();
+        let pids = fs::read_dir("/proc")?.flatten().filter_map(|dir| {
+            if is_str_numeric(dir.file_name().to_string_lossy().trim()) {
+                Some(dir.path())
+            } else {
+                None
+            }
+        });
 
-                        if let Ok((process_harvest, new_process_times)) = read_proc(
-                            prev_proc_details,
-                            &process,
-                            cpu_usage,
-                            cpu_fraction,
-                            use_current_cpu_total,
-                            time_difference_in_secs,
-                            total_memory,
-                            user_table,
-                        ) {
-                            prev_proc_details.cpu_time = new_process_times;
-                            prev_proc_details.total_read_bytes = process_harvest.total_read_bytes;
-                            prev_proc_details.total_write_bytes = process_harvest.total_write_bytes;
+        let process_vector: Vec<ProcessHarvest> = pids
+            .filter_map(|pid_path| {
+                if let Ok(process) = Process::from_path(pid_path) {
+                    let pid = process.pid;
+                    let prev_proc_details = pid_mapping.entry(pid).or_default();
 
-                            pids_to_clear.remove(&pid);
-                            return Some(process_harvest);
-                        }
+                    if let Ok((process_harvest, new_process_times)) = read_proc(
+                        prev_proc_details,
+                        process,
+                        cpu_usage,
+                        cpu_fraction,
+                        use_current_cpu_total,
+                        time_difference_in_secs,
+                        total_memory,
+                        user_table,
+                    ) {
+                        prev_proc_details.cpu_time = new_process_times;
+                        prev_proc_details.total_read_bytes = process_harvest.total_read_bytes;
+                        prev_proc_details.total_write_bytes = process_harvest.total_write_bytes;
+
+                        pids_to_clear.remove(&pid);
+                        return Some(process_harvest);
                     }
                 }
 
@@ -328,37 +366,37 @@ mod tests {
     fn test_proc_cpu_parse() {
         assert_eq!(
             (100_f64, 200_f64),
-            calculate_idle_values("100 0 100 100"),
+            fetch_cpu_usage("100 0 100 100"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 4 values"
         );
         assert_eq!(
             (120_f64, 200_f64),
-            calculate_idle_values("100 0 100 100 20"),
+            fetch_cpu_usage("100 0 100 100 20"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 5 values"
         );
         assert_eq!(
             (120_f64, 230_f64),
-            calculate_idle_values("100 0 100 100 20 30"),
+            fetch_cpu_usage("100 0 100 100 20 30"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 6 values"
         );
         assert_eq!(
             (120_f64, 270_f64),
-            calculate_idle_values("100 0 100 100 20 30 40"),
+            fetch_cpu_usage("100 0 100 100 20 30 40"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 7 values"
         );
         assert_eq!(
             (120_f64, 320_f64),
-            calculate_idle_values("100 0 100 100 20 30 40 50"),
+            fetch_cpu_usage("100 0 100 100 20 30 40 50"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 8 values"
         );
         assert_eq!(
             (120_f64, 320_f64),
-            calculate_idle_values("100 0 100 100 20 30 40 50 100"),
+            fetch_cpu_usage("100 0 100 100 20 30 40 50 100"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 9 values"
         );
         assert_eq!(
             (120_f64, 320_f64),
-            calculate_idle_values("100 0 100 100 20 30 40 50 100 200"),
+            fetch_cpu_usage("100 0 100 100 20 30 40 50 100 200"),
             "Failed to properly calculate idle/non-idle for /proc/stat CPU with 10 values"
         );
     }
