@@ -1,7 +1,5 @@
 use std::collections::BTreeMap;
 
-use typed_builder::*;
-
 use crate::constants::DEFAULT_WIDGET_ID;
 use crate::error::{BottomError, Result};
 
@@ -535,292 +533,317 @@ impl BottomLayout {
 
     pub fn init_basic_default(use_battery: bool) -> Self {
         let table_widgets = if use_battery {
+            let disk_widget = BottomWidget::new(BottomWidgetType::Disk, 4)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .left_neighbour(Some(8))
+                .right_neighbour(Some(DEFAULT_WIDGET_ID + 2));
+
+            let proc_sort = BottomWidget::new(BottomWidgetType::ProcSort, DEFAULT_WIDGET_ID + 2)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
+                .left_neighbour(Some(4))
+                .right_neighbour(Some(DEFAULT_WIDGET_ID))
+                .width_ratio(1)
+                .parent_reflector(Some((WidgetDirection::Right, 2)));
+
+            let proc = BottomWidget::new(BottomWidgetType::Proc, DEFAULT_WIDGET_ID)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
+                .left_neighbour(Some(DEFAULT_WIDGET_ID + 2))
+                .right_neighbour(Some(7))
+                .width_ratio(2);
+
+            let proc_search =
+                BottomWidget::new(BottomWidgetType::ProcSearch, DEFAULT_WIDGET_ID + 1)
+                    .canvas_handle_width(true)
+                    .up_neighbour(Some(DEFAULT_WIDGET_ID))
+                    .left_neighbour(Some(4))
+                    .right_neighbour(Some(7))
+                    .parent_reflector(Some((WidgetDirection::Up, 1)));
+
+            let temp = BottomWidget::new(BottomWidgetType::Temp, 7)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .left_neighbour(Some(DEFAULT_WIDGET_ID))
+                .right_neighbour(Some(8));
+
+            let battery = BottomWidget::new(BottomWidgetType::Battery, 8)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .left_neighbour(Some(7))
+                .right_neighbour(Some(4));
+
             vec![
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![BottomColRow::builder()
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![disk_widget]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![proc_sort, proc])
                         .canvas_handle_height(true)
-                        .children(vec![BottomWidget::builder()
-                            .canvas_handle_width(true)
-                            .widget_type(BottomWidgetType::Disk)
-                            .widget_id(4)
-                            .up_neighbour(Some(100))
-                            .left_neighbour(Some(8))
-                            .right_neighbour(Some(DEFAULT_WIDGET_ID + 2))
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![
-                        BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .total_widget_ratio(3)
-                            .children(vec![
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::ProcSort)
-                                    .widget_id(DEFAULT_WIDGET_ID + 2)
-                                    .up_neighbour(Some(100))
-                                    .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
-                                    .left_neighbour(Some(4))
-                                    .right_neighbour(Some(DEFAULT_WIDGET_ID))
-                                    .width_ratio(1)
-                                    .parent_reflector(Some((WidgetDirection::Right, 2)))
-                                    .build(),
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::Proc)
-                                    .widget_id(DEFAULT_WIDGET_ID)
-                                    .up_neighbour(Some(100))
-                                    .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
-                                    .left_neighbour(Some(DEFAULT_WIDGET_ID + 2))
-                                    .right_neighbour(Some(7))
-                                    .width_ratio(2)
-                                    .build(),
-                            ])
-                            .build(),
-                        BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![BottomWidget::builder()
-                                .canvas_handle_width(true)
-                                .widget_type(BottomWidgetType::ProcSearch)
-                                .widget_id(DEFAULT_WIDGET_ID + 1)
-                                .up_neighbour(Some(DEFAULT_WIDGET_ID))
-                                .left_neighbour(Some(4))
-                                .right_neighbour(Some(7))
-                                .parent_reflector(Some((WidgetDirection::Up, 1)))
-                                .build()])
-                            .build(),
-                    ])
-                    .build(),
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![BottomColRow::builder()
-                        .canvas_handle_height(true)
-                        .children(vec![BottomWidget::builder()
-                            .canvas_handle_width(true)
-                            .widget_type(BottomWidgetType::Temp)
-                            .widget_id(7)
-                            .up_neighbour(Some(100))
-                            .left_neighbour(Some(DEFAULT_WIDGET_ID))
-                            .right_neighbour(Some(8))
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![BottomColRow::builder()
-                        .canvas_handle_height(true)
-                        .children(vec![BottomWidget::builder()
-                            .canvas_handle_width(true)
-                            .widget_type(BottomWidgetType::Battery)
-                            .widget_id(8)
-                            .up_neighbour(Some(100))
-                            .left_neighbour(Some(7))
-                            .right_neighbour(Some(4))
-                            .build()])
-                        .build()])
-                    .build(),
+                        .total_widget_ratio(3),
+                    BottomColRow::new(vec![proc_search]).canvas_handle_height(true),
+                ])
+                .canvas_handle_width(true),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![temp]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![battery]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true),
             ]
         } else {
+            let disk = BottomWidget::new(BottomWidgetType::Disk, 4)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .left_neighbour(Some(7))
+                .right_neighbour(Some(DEFAULT_WIDGET_ID + 2));
+
+            let proc_sort = BottomWidget::new(BottomWidgetType::ProcSort, DEFAULT_WIDGET_ID + 2)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
+                .left_neighbour(Some(4))
+                .right_neighbour(Some(DEFAULT_WIDGET_ID))
+                .parent_reflector(Some((WidgetDirection::Right, 2)));
+
+            let proc = BottomWidget::new(BottomWidgetType::Proc, DEFAULT_WIDGET_ID)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
+                .left_neighbour(Some(DEFAULT_WIDGET_ID + 2))
+                .right_neighbour(Some(7));
+
+            let proc_search =
+                BottomWidget::new(BottomWidgetType::ProcSearch, DEFAULT_WIDGET_ID + 1)
+                    .canvas_handle_width(true)
+                    .up_neighbour(Some(DEFAULT_WIDGET_ID))
+                    .left_neighbour(Some(4))
+                    .right_neighbour(Some(7))
+                    .parent_reflector(Some((WidgetDirection::Up, 1)));
+
+            let temp = BottomWidget::new(BottomWidgetType::Temp, 7)
+                .canvas_handle_width(true)
+                .up_neighbour(Some(100))
+                .left_neighbour(Some(DEFAULT_WIDGET_ID))
+                .right_neighbour(Some(4));
+
             vec![
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![BottomColRow::builder()
-                        .canvas_handle_height(true)
-                        .children(vec![BottomWidget::builder()
-                            .canvas_handle_width(true)
-                            .widget_type(BottomWidgetType::Disk)
-                            .widget_id(4)
-                            .up_neighbour(Some(100))
-                            .left_neighbour(Some(7))
-                            .right_neighbour(Some(DEFAULT_WIDGET_ID + 2))
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![
-                        BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::ProcSort)
-                                    .widget_id(DEFAULT_WIDGET_ID + 2)
-                                    .up_neighbour(Some(100))
-                                    .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
-                                    .left_neighbour(Some(4))
-                                    .right_neighbour(Some(DEFAULT_WIDGET_ID))
-                                    .parent_reflector(Some((WidgetDirection::Right, 2)))
-                                    .build(),
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::Proc)
-                                    .widget_id(DEFAULT_WIDGET_ID)
-                                    .up_neighbour(Some(100))
-                                    .down_neighbour(Some(DEFAULT_WIDGET_ID + 1))
-                                    .left_neighbour(Some(DEFAULT_WIDGET_ID + 2))
-                                    .right_neighbour(Some(7))
-                                    .build(),
-                            ])
-                            .build(),
-                        BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![BottomWidget::builder()
-                                .canvas_handle_width(true)
-                                .widget_type(BottomWidgetType::ProcSearch)
-                                .widget_id(DEFAULT_WIDGET_ID + 1)
-                                .up_neighbour(Some(DEFAULT_WIDGET_ID))
-                                .left_neighbour(Some(4))
-                                .right_neighbour(Some(7))
-                                .parent_reflector(Some((WidgetDirection::Up, 1)))
-                                .build()])
-                            .build(),
-                    ])
-                    .build(),
-                BottomCol::builder()
-                    .canvas_handle_width(true)
-                    .children(vec![BottomColRow::builder()
-                        .canvas_handle_height(true)
-                        .children(vec![BottomWidget::builder()
-                            .canvas_handle_width(true)
-                            .widget_type(BottomWidgetType::Temp)
-                            .widget_id(7)
-                            .up_neighbour(Some(100))
-                            .left_neighbour(Some(DEFAULT_WIDGET_ID))
-                            .right_neighbour(Some(4))
-                            .build()])
-                        .build()])
-                    .build(),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![disk]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![proc_sort, proc]).canvas_handle_height(true),
+                    BottomColRow::new(vec![proc_search]).canvas_handle_height(true),
+                ])
+                .canvas_handle_width(true),
+                BottomCol::new(vec![
+                    BottomColRow::new(vec![temp]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true),
             ]
         };
 
+        let cpu = BottomWidget::new(BottomWidgetType::BasicCpu, 1)
+            .canvas_handle_width(true)
+            .down_neighbour(Some(2));
+
+        let mem = BottomWidget::new(BottomWidgetType::BasicMem, 2)
+            .canvas_handle_width(true)
+            .up_neighbour(Some(1))
+            .down_neighbour(Some(100))
+            .right_neighbour(Some(3));
+
+        let net = BottomWidget::new(BottomWidgetType::BasicNet, 3)
+            .canvas_handle_width(true)
+            .up_neighbour(Some(1))
+            .down_neighbour(Some(100))
+            .left_neighbour(Some(2));
+
+        let table = BottomWidget::new(BottomWidgetType::BasicTables, 100)
+            .canvas_handle_width(true)
+            .up_neighbour(Some(2));
+
         BottomLayout {
             total_row_height_ratio: 3,
             rows: vec![
-                BottomRow::builder()
-                    .canvas_handle_height(true)
-                    .children(vec![BottomCol::builder()
-                        .canvas_handle_width(true)
-                        .children(vec![BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![BottomWidget::builder()
-                                .canvas_handle_width(true)
-                                .widget_type(BottomWidgetType::BasicCpu)
-                                .widget_id(1)
-                                .down_neighbour(Some(2))
-                                .build()])
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomRow::builder()
-                    .canvas_handle_height(true)
-                    .children(vec![BottomCol::builder()
-                        .canvas_handle_width(true)
-                        .children(vec![BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::BasicMem)
-                                    .widget_id(2)
-                                    .up_neighbour(Some(1))
-                                    .down_neighbour(Some(100))
-                                    .right_neighbour(Some(3))
-                                    .build(),
-                                BottomWidget::builder()
-                                    .canvas_handle_width(true)
-                                    .widget_type(BottomWidgetType::BasicNet)
-                                    .widget_id(3)
-                                    .up_neighbour(Some(1))
-                                    .down_neighbour(Some(100))
-                                    .left_neighbour(Some(2))
-                                    .build(),
-                            ])
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomRow::builder()
-                    .canvas_handle_height(true)
-                    .children(vec![BottomCol::builder()
-                        .canvas_handle_width(true)
-                        .children(vec![BottomColRow::builder()
-                            .canvas_handle_height(true)
-                            .children(vec![BottomWidget::builder()
-                                .canvas_handle_width(true)
-                                .widget_type(BottomWidgetType::BasicTables)
-                                .widget_id(100)
-                                .up_neighbour(Some(2))
-                                .build()])
-                            .build()])
-                        .build()])
-                    .build(),
-                BottomRow::builder()
-                    .canvas_handle_height(true)
-                    .children(table_widgets)
-                    .build(),
+                BottomRow::new(vec![BottomCol::new(vec![
+                    BottomColRow::new(vec![cpu]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true)])
+                .canvas_handle_height(true),
+                BottomRow::new(vec![BottomCol::new(vec![BottomColRow::new(vec![
+                    mem, net,
+                ])
+                .canvas_handle_height(true)])
+                .canvas_handle_width(true)])
+                .canvas_handle_height(true),
+                BottomRow::new(vec![BottomCol::new(vec![
+                    BottomColRow::new(vec![table]).canvas_handle_height(true)
+                ])
+                .canvas_handle_width(true)])
+                .canvas_handle_height(true),
+                BottomRow::new(table_widgets).canvas_handle_height(true),
             ],
         }
     }
 }
 
+// pub enum BottomLayoutNode {
+//     Container(BottomContainer),
+//     Widget(BottomWidget),
+// }
+
+// pub struct BottomContainer {
+//     children: Vec<BottomLayoutNode>,
+//     root_ratio: u32,
+//     growth_type: BottomLayoutNodeSizing,
+// }
+
+// pub enum BottomContainerType {
+//     Row,
+//     Col,
+// }
+
+// pub enum BottomLayoutNodeSizing {
+//     Ratio(u32),
+//     CanvasHandles,
+//     FlexGrow,
+// }
+
 /// Represents a single row in the layout.
-#[derive(Clone, Debug, TypedBuilder)]
+#[derive(Clone, Debug)]
 pub struct BottomRow {
     pub children: Vec<BottomCol>,
-
-    #[builder(default = 1)]
     pub total_col_ratio: u32,
-
-    #[builder(default = 1)]
     pub row_height_ratio: u32,
-
-    #[builder(default = false)]
     pub canvas_handle_height: bool,
-
-    #[builder(default = false)]
     pub flex_grow: bool,
 }
 
+impl BottomRow {
+    pub fn new(children: Vec<BottomCol>) -> Self {
+        Self {
+            children,
+            total_col_ratio: 1,
+            row_height_ratio: 1,
+            canvas_handle_height: false,
+            flex_grow: false,
+        }
+    }
+
+    pub fn total_col_ratio(mut self, total_col_ratio: u32) -> Self {
+        self.total_col_ratio = total_col_ratio;
+        self
+    }
+
+    pub fn row_height_ratio(mut self, row_height_ratio: u32) -> Self {
+        self.row_height_ratio = row_height_ratio;
+        self
+    }
+
+    pub fn canvas_handle_height(mut self, canvas_handle_height: bool) -> Self {
+        self.canvas_handle_height = canvas_handle_height;
+        self
+    }
+
+    pub fn flex_grow(mut self, flex_grow: bool) -> Self {
+        self.flex_grow = flex_grow;
+        self
+    }
+}
+
 /// Represents a single column in the layout.  We assume that even if the column
 /// contains only ONE element, it is still a column (rather than either a col or
 /// a widget, as per the config, for simplicity's sake).
-#[derive(Clone, Debug, TypedBuilder)]
+#[derive(Clone, Debug)]
 pub struct BottomCol {
     pub children: Vec<BottomColRow>,
-
-    #[builder(default = 1)]
     pub total_col_row_ratio: u32,
-
-    #[builder(default = 1)]
     pub col_width_ratio: u32,
-
-    #[builder(default = false)]
     pub canvas_handle_width: bool,
-
-    #[builder(default = false)]
     pub flex_grow: bool,
 }
 
-#[derive(Clone, Default, Debug, TypedBuilder)]
+impl BottomCol {
+    pub fn new(children: Vec<BottomColRow>) -> Self {
+        Self {
+            children,
+            total_col_row_ratio: 1,
+            col_width_ratio: 1,
+            canvas_handle_width: false,
+            flex_grow: false,
+        }
+    }
+
+    pub fn total_col_row_ratio(mut self, total_col_row_ratio: u32) -> Self {
+        self.total_col_row_ratio = total_col_row_ratio;
+        self
+    }
+
+    pub fn col_width_ratio(mut self, col_width_ratio: u32) -> Self {
+        self.col_width_ratio = col_width_ratio;
+        self
+    }
+
+    pub fn canvas_handle_width(mut self, canvas_handle_width: bool) -> Self {
+        self.canvas_handle_width = canvas_handle_width;
+        self
+    }
+
+    pub fn flex_grow(mut self, flex_grow: bool) -> Self {
+        self.flex_grow = flex_grow;
+        self
+    }
+}
+
+#[derive(Clone, Default, Debug)]
 pub struct BottomColRow {
     pub children: Vec<BottomWidget>,
-
-    #[builder(default = 1)]
     pub total_widget_ratio: u32,
-
-    #[builder(default = 1)]
     pub col_row_height_ratio: u32,
-
-    #[builder(default = false)]
     pub canvas_handle_height: bool,
-
-    #[builder(default = false)]
     pub flex_grow: bool,
 }
 
+impl BottomColRow {
+    pub(crate) fn new(children: Vec<BottomWidget>) -> Self {
+        Self {
+            children,
+            total_widget_ratio: 1,
+            col_row_height_ratio: 1,
+            canvas_handle_height: false,
+            flex_grow: false,
+        }
+    }
+
+    pub(crate) fn total_widget_ratio(mut self, total_widget_ratio: u32) -> Self {
+        self.total_widget_ratio = total_widget_ratio;
+        self
+    }
+
+    pub(crate) fn col_row_height_ratio(mut self, col_row_height_ratio: u32) -> Self {
+        self.col_row_height_ratio = col_row_height_ratio;
+        self
+    }
+
+    pub(crate) fn canvas_handle_height(mut self, canvas_handle_height: bool) -> Self {
+        self.canvas_handle_height = canvas_handle_height;
+        self
+    }
+
+    pub(crate) fn flex_grow(mut self, flex_grow: bool) -> Self {
+        self.flex_grow = flex_grow;
+        self
+    }
+}
+
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub enum WidgetDirection {
     Left,
@@ -831,57 +854,105 @@ pub enum WidgetDirection {
 
 impl WidgetDirection {
     pub fn is_opposite(&self, other_direction: &WidgetDirection) -> bool {
-        match &self {
-            WidgetDirection::Left => *other_direction == WidgetDirection::Right,
-            WidgetDirection::Right => *other_direction == WidgetDirection::Left,
-            WidgetDirection::Up => *other_direction == WidgetDirection::Down,
-            WidgetDirection::Down => *other_direction == WidgetDirection::Up,
-        }
+        let to_compare = match &self {
+            WidgetDirection::Left => WidgetDirection::Right,
+            WidgetDirection::Right => WidgetDirection::Left,
+            WidgetDirection::Up => WidgetDirection::Down,
+            WidgetDirection::Down => WidgetDirection::Up,
+        };
+
+        *other_direction == to_compare
     }
 }
 
 /// Represents a single widget.
-#[derive(Debug, Default, Clone, TypedBuilder)]
+#[derive(Debug, Default, Clone)]
 pub struct BottomWidget {
     pub widget_type: BottomWidgetType,
     pub widget_id: u64,
-
-    #[builder(default = 1)]
     pub width_ratio: u32,
-
-    #[builder(default = None)]
     pub left_neighbour: Option<u64>,
-
-    #[builder(default = None)]
     pub right_neighbour: Option<u64>,
-
-    #[builder(default = None)]
     pub up_neighbour: Option<u64>,
-
-    #[builder(default = None)]
     pub down_neighbour: Option<u64>,
 
     /// If set to true, the canvas will override any ratios.
-    #[builder(default = false)]
     pub canvas_handle_width: bool,
 
     /// Whether we want this widget to take up all available room (and ignore any ratios).
-    #[builder(default = false)]
     pub flex_grow: bool,
 
     /// The value is the direction to bounce, as well as the parent offset.
-    #[builder(default = None)]
     pub parent_reflector: Option<(WidgetDirection, u64)>,
 
     /// Top left corner when drawn, for mouse click detection. (x, y)
-    #[builder(default = None)]
     pub top_left_corner: Option<(u16, u16)>,
 
     /// Bottom right corner when drawn, for mouse click detection. (x, y)
-    #[builder(default = None)]
     pub bottom_right_corner: Option<(u16, u16)>,
 }
 
+impl BottomWidget {
+    pub(crate) fn new(widget_type: BottomWidgetType, widget_id: u64) -> Self {
+        Self {
+            widget_type,
+            widget_id,
+            width_ratio: 1,
+            left_neighbour: None,
+            right_neighbour: None,
+            up_neighbour: None,
+            down_neighbour: None,
+            canvas_handle_width: false,
+            flex_grow: false,
+            parent_reflector: None,
+            top_left_corner: None,
+            bottom_right_corner: None,
+        }
+    }
+
+    pub(crate) fn width_ratio(mut self, width_ratio: u32) -> Self {
+        self.width_ratio = width_ratio;
+        self
+    }
+
+    pub(crate) fn left_neighbour(mut self, left_neighbour: Option<u64>) -> Self {
+        self.left_neighbour = left_neighbour;
+        self
+    }
+
+    pub(crate) fn right_neighbour(mut self, right_neighbour: Option<u64>) -> Self {
+        self.right_neighbour = right_neighbour;
+        self
+    }
+
+    pub(crate) fn up_neighbour(mut self, up_neighbour: Option<u64>) -> Self {
+        self.up_neighbour = up_neighbour;
+        self
+    }
+
+    pub(crate) fn down_neighbour(mut self, down_neighbour: Option<u64>) -> Self {
+        self.down_neighbour = down_neighbour;
+        self
+    }
+
+    pub(crate) fn canvas_handle_width(mut self, canvas_handle_width: bool) -> Self {
+        self.canvas_handle_width = canvas_handle_width;
+        self
+    }
+
+    pub(crate) fn flex_grow(mut self, flex_grow: bool) -> Self {
+        self.flex_grow = flex_grow;
+        self
+    }
+
+    pub(crate) fn parent_reflector(
+        mut self, parent_reflector: Option<(WidgetDirection, u64)>,
+    ) -> Self {
+        self.parent_reflector = parent_reflector;
+        self
+    }
+}
+
 #[derive(Debug, Clone, Eq, PartialEq, Hash, Default)]
 pub enum BottomWidgetType {
     #[default]
