@@ -1,11 +1,11 @@
-#[cfg(target_family = "unix")]
+#[cfg(any(target_os = "freebsd", target_os = "linux", target_os = "macos"))]
 use std::cmp::min;
 
 use tui::{
     backend::Backend,
     layout::{Alignment, Constraint, Direction, Layout, Rect},
     terminal::Frame,
-    text::{Span, Spans, Text},
+    text::{Line, Span, Text},
     widgets::{Block, Borders, Paragraph, Wrap},
 };
 
@@ -18,20 +18,163 @@ use crate::{
 const DD_BASE: &str = " Confirm Kill Process ── Esc to close ";
 const DD_ERROR_BASE: &str = " Error ── Esc to close ";
 
+cfg_if::cfg_if! {
+    if #[cfg(target_os = "linux")] {
+        const SIGNAL_TEXT: [&str; 63] = [
+            "0: Cancel",
+            "1: HUP",
+            "2: INT",
+            "3: QUIT",
+            "4: ILL",
+            "5: TRAP",
+            "6: ABRT",
+            "7: BUS",
+            "8: FPE",
+            "9: KILL",
+            "10: USR1",
+            "11: SEGV",
+            "12: USR2",
+            "13: PIPE",
+            "14: ALRM",
+            "15: TERM",
+            "16: STKFLT",
+            "17: CHLD",
+            "18: CONT",
+            "19: STOP",
+            "20: TSTP",
+            "21: TTIN",
+            "22: TTOU",
+            "23: URG",
+            "24: XCPU",
+            "25: XFSZ",
+            "26: VTALRM",
+            "27: PROF",
+            "28: WINCH",
+            "29: IO",
+            "30: PWR",
+            "31: SYS",
+            "34: RTMIN",
+            "35: RTMIN+1",
+            "36: RTMIN+2",
+            "37: RTMIN+3",
+            "38: RTMIN+4",
+            "39: RTMIN+5",
+            "40: RTMIN+6",
+            "41: RTMIN+7",
+            "42: RTMIN+8",
+            "43: RTMIN+9",
+            "44: RTMIN+10",
+            "45: RTMIN+11",
+            "46: RTMIN+12",
+            "47: RTMIN+13",
+            "48: RTMIN+14",
+            "49: RTMIN+15",
+            "50: RTMAX-14",
+            "51: RTMAX-13",
+            "52: RTMAX-12",
+            "53: RTMAX-11",
+            "54: RTMAX-10",
+            "55: RTMAX-9",
+            "56: RTMAX-8",
+            "57: RTMAX-7",
+            "58: RTMAX-6",
+            "59: RTMAX-5",
+            "60: RTMAX-4",
+            "61: RTMAX-3",
+            "62: RTMAX-2",
+            "63: RTMAX-1",
+            "64: RTMAX",
+        ];
+    } else if #[cfg(target_os = "macos")] {
+        const SIGNAL_TEXT: [&str; 32] = [
+            "0: Cancel",
+            "1: HUP",
+            "2: INT",
+            "3: QUIT",
+            "4: ILL",
+            "5: TRAP",
+            "6: ABRT",
+            "7: EMT",
+            "8: FPE",
+            "9: KILL",
+            "10: BUS",
+            "11: SEGV",
+            "12: SYS",
+            "13: PIPE",
+            "14: ALRM",
+            "15: TERM",
+            "16: URG",
+            "17: STOP",
+            "18: TSTP",
+            "19: CONT",
+            "20: CHLD",
+            "21: TTIN",
+            "22: TTOU",
+            "23: IO",
+            "24: XCPU",
+            "25: XFSZ",
+            "26: VTALRM",
+            "27: PROF",
+            "28: WINCH",
+            "29: INFO",
+            "30: USR1",
+            "31: USR2",
+        ];
+    } else if #[cfg(target_os = "freebsd")] {
+        const SIGNAL_TEXT: [&str; 34] = [
+            "0: Cancel",
+            "1: HUP",
+            "2: INT",
+            "3: QUIT",
+            "4: ILL",
+            "5: TRAP",
+            "6: ABRT",
+            "7: EMT",
+            "8: FPE",
+            "9: KILL",
+            "10: BUS",
+            "11: SEGV",
+            "12: SYS",
+            "13: PIPE",
+            "14: ALRM",
+            "15: TERM",
+            "16: URG",
+            "17: STOP",
+            "18: TSTP",
+            "19: CONT",
+            "20: CHLD",
+            "21: TTIN",
+            "22: TTOU",
+            "23: IO",
+            "24: XCPU",
+            "25: XFSZ",
+            "26: VTALRM",
+            "27: PROF",
+            "28: WINCH",
+            "29: INFO",
+            "30: USR1",
+            "31: USR2",
+            "32: THR",
+            "33: LIBRT",
+        ];
+    }
+}
+
 impl Painter {
     pub fn get_dd_spans(&self, app_state: &App) -> Option<Text<'_>> {
         if let Some(dd_err) = &app_state.dd_err {
             return Some(Text::from(vec![
-                Spans::default(),
-                Spans::from("Failed to kill process."),
-                Spans::from(dd_err.clone()),
-                Spans::from("Please press ENTER or ESC to close this dialog."),
+                Line::default(),
+                Line::from("Failed to kill process."),
+                Line::from(dd_err.clone()),
+                Line::from("Please press ENTER or ESC to close this dialog."),
             ]));
         } else if let Some(to_kill_processes) = app_state.get_to_delete_processes() {
             if let Some(first_pid) = to_kill_processes.1.first() {
                 return Some(Text::from(vec![
-                    Spans::from(""),
+                    Line::from(""),
                     if app_state
+                        .states
                         .proc_state
                         .widget_states
                         .get(&app_state.current_widget.widget_id)
@@ -39,19 +182,19 @@ impl Painter {
                         .unwrap_or(false)
                     {
                         if to_kill_processes.1.len() != 1 {
-                            Spans::from(format!(
+                            Line::from(format!(
                                 "Kill {} processes with the name \"{}\"?  Press ENTER to confirm.",
                                 to_kill_processes.1.len(),
                                 to_kill_processes.0
                             ))
                         } else {
-                            Spans::from(format!(
+                            Line::from(format!(
                                 "Kill 1 process with the name \"{}\"?  Press ENTER to confirm.",
                                 to_kill_processes.0
                             ))
                         }
                     } else {
-                        Spans::from(format!(
+                        Line::from(format!(
                             "Kill process \"{}\" with PID {}?  Press ENTER to confirm.",
                             to_kill_processes.0, first_pid
                         ))
@@ -133,154 +276,8 @@ impl Painter {
                 ];
             }
         } else {
-            #[cfg(target_family = "unix")]
+            #[cfg(any(target_os = "freebsd", target_os = "linux", target_os = "macos"))]
             {
-                let signal_text: Vec<&str>;
-                #[cfg(target_os = "linux")]
-                {
-                    signal_text = vec![
-                        "0: Cancel",
-                        "1: HUP",
-                        "2: INT",
-                        "3: QUIT",
-                        "4: ILL",
-                        "5: TRAP",
-                        "6: ABRT",
-                        "7: BUS",
-                        "8: FPE",
-                        "9: KILL",
-                        "10: USR1",
-                        "11: SEGV",
-                        "12: USR2",
-                        "13: PIPE",
-                        "14: ALRM",
-                        "15: TERM",
-                        "16: STKFLT",
-                        "17: CHLD",
-                        "18: CONT",
-                        "19: STOP",
-                        "20: TSTP",
-                        "21: TTIN",
-                        "22: TTOU",
-                        "23: URG",
-                        "24: XCPU",
-                        "25: XFSZ",
-                        "26: VTALRM",
-                        "27: PROF",
-                        "28: WINCH",
-                        "29: IO",
-                        "30: PWR",
-                        "31: SYS",
-                        "34: RTMIN",
-                        "35: RTMIN+1",
-                        "36: RTMIN+2",
-                        "37: RTMIN+3",
-                        "38: RTMIN+4",
-                        "39: RTMIN+5",
-                        "40: RTMIN+6",
-                        "41: RTMIN+7",
-                        "42: RTMIN+8",
-                        "43: RTMIN+9",
-                        "44: RTMIN+10",
-                        "45: RTMIN+11",
-                        "46: RTMIN+12",
-                        "47: RTMIN+13",
-                        "48: RTMIN+14",
-                        "49: RTMIN+15",
-                        "50: RTMAX-14",
-                        "51: RTMAX-13",
-                        "52: RTMAX-12",
-                        "53: RTMAX-11",
-                        "54: RTMAX-10",
-                        "55: RTMAX-9",
-                        "56: RTMAX-8",
-                        "57: RTMAX-7",
-                        "58: RTMAX-6",
-                        "59: RTMAX-5",
-                        "60: RTMAX-4",
-                        "61: RTMAX-3",
-                        "62: RTMAX-2",
-                        "63: RTMAX-1",
-                        "64: RTMAX",
-                    ];
-                }
-                #[cfg(target_os = "macos")]
-                {
-                    signal_text = vec![
-                        "0: Cancel",
-                        "1: HUP",
-                        "2: INT",
-                        "3: QUIT",
-                        "4: ILL",
-                        "5: TRAP",
-                        "6: ABRT",
-                        "7: EMT",
-                        "8: FPE",
-                        "9: KILL",
-                        "10: BUS",
-                        "11: SEGV",
-                        "12: SYS",
-                        "13: PIPE",
-                        "14: ALRM",
-                        "15: TERM",
-                        "16: URG",
-                        "17: STOP",
-                        "18: TSTP",
-                        "19: CONT",
-                        "20: CHLD",
-                        "21: TTIN",
-                        "22: TTOU",
-                        "23: IO",
-                        "24: XCPU",
-                        "25: XFSZ",
-                        "26: VTALRM",
-                        "27: PROF",
-                        "28: WINCH",
-                        "29: INFO",
-                        "30: USR1",
-                        "31: USR2",
-                    ];
-                }
-                #[cfg(target_os = "freebsd")]
-                {
-                    signal_text = vec![
-                        "0: Cancel",
-                        "1: HUP",
-                        "2: INT",
-                        "3: QUIT",
-                        "4: ILL",
-                        "5: TRAP",
-                        "6: ABRT",
-                        "7: EMT",
-                        "8: FPE",
-                        "9: KILL",
-                        "10: BUS",
-                        "11: SEGV",
-                        "12: SYS",
-                        "13: PIPE",
-                        "14: ALRM",
-                        "15: TERM",
-                        "16: URG",
-                        "17: STOP",
-                        "18: TSTP",
-                        "19: CONT",
-                        "20: CHLD",
-                        "21: TTIN",
-                        "22: TTOU",
-                        "23: IO",
-                        "24: XCPU",
-                        "25: XFSZ",
-                        "26: VTALRM",
-                        "27: PROF",
-                        "28: WINCH",
-                        "29: INFO",
-                        "30: USR1",
-                        "31: USR2",
-                        "32: THR",
-                        "33: LIBRT",
-                    ];
-                }
-
                 let button_rect = Layout::default()
                     .direction(Direction::Horizontal)
                     .margin(1)
@@ -320,14 +317,14 @@ impl Painter {
                 };
                 let scroll_offset: usize = app_state.delete_dialog_state.scroll_pos;
 
-                let mut buttons = signal_text
-                    [scroll_offset + 1..min((layout.len()) + scroll_offset, signal_text.len())]
+                let mut buttons = SIGNAL_TEXT
+                    [scroll_offset + 1..min((layout.len()) + scroll_offset, SIGNAL_TEXT.len())]
                     .iter()
                     .map(|text| Span::styled(*text, self.colours.text_style))
                     .collect::<Vec<Span<'_>>>();
-                buttons.insert(0, Span::styled(signal_text[0], self.colours.text_style));
+                buttons.insert(0, Span::styled(SIGNAL_TEXT[0], self.colours.text_style));
                 buttons[selected - scroll_offset] = Span::styled(
-                    signal_text[selected],
+                    SIGNAL_TEXT[selected],
                     self.colours.currently_selected_text_style,
                 );
 
@@ -357,7 +354,7 @@ impl Painter {
     ) -> bool {
         if let Some(dd_text) = dd_text {
             let dd_title = if app_state.dd_err.is_some() {
-                Spans::from(vec![
+                Line::from(vec![
                     Span::styled(" Error ", self.colours.widget_title_style),
                     Span::styled(
                         format!(
@@ -371,7 +368,7 @@ impl Painter {
                     ),
                 ])
             } else {
-                Spans::from(vec![
+                Line::from(vec![
                     Span::styled(" Confirm Kill Process ", self.colours.widget_title_style),
                     Span::styled(
                         format!(
