@@ -5,15 +5,19 @@
 //! than the actual usage of the application. If you are instead looking for documentation regarding the *usage* of
 //! bottom, refer to [here](https://clementtsang.github.io/bottom/stable/).
 
-#![warn(rust_2018_idioms)]
+#![deny(rust_2018_idioms)]
 #![deny(clippy::todo)]
 #![deny(clippy::unimplemented)]
 #![deny(clippy::missing_safety_doc)]
-#[allow(unused_imports)] // TODO: Deny unused imports.
-// Only used for builds not intended for release.
-#[cfg(feature = "log")]
-#[macro_use]
-extern crate log;
+
+// Primarily used for debug purposes.
+cfg_if::cfg_if! {
+    if #[cfg(feature = "log")] {
+        #[allow(unused_imports)]
+        #[macro_use]
+        extern crate log;
+    }
+}
 
 use std::{
     boxed::Box,
@@ -71,6 +75,7 @@ pub type Pid = usize;
 #[cfg(target_family = "unix")]
 pub type Pid = libc::pid_t;
 
+/// Events sent to the main thread.
 #[derive(Debug)]
 pub enum BottomEvent {
     Resize,
@@ -79,14 +84,13 @@ pub enum BottomEvent {
     PasteEvent(String),
     Update(Box<data_harvester::Data>),
     Clean,
+    Terminate,
 }
 
+/// Events sent to the collection thread.
 #[derive(Debug)]
-pub enum ThreadControlEvent {
+pub enum CollectionThreadEvent {
     Reset,
-    UpdateConfig(Box<AppConfigFields>),
-    UpdateUsedWidgets(Box<UsedWidgets>),
-    UpdateUpdateTime(u64),
 }
 
 pub fn handle_mouse_event(event: MouseEvent, app: &mut App) {
@@ -111,7 +115,7 @@ pub fn handle_mouse_event(event: MouseEvent, app: &mut App) {
 }
 
 pub fn handle_key_event_or_break(
-    event: KeyEvent, app: &mut App, reset_sender: &Sender<ThreadControlEvent>,
+    event: KeyEvent, app: &mut App, reset_sender: &Sender<CollectionThreadEvent>,
 ) -> bool {
     // debug!("KeyEvent: {:?}", event);
 
@@ -168,7 +172,7 @@ pub fn handle_key_event_or_break(
                 KeyCode::Up => app.move_widget_selection(&WidgetDirection::Up),
                 KeyCode::Down => app.move_widget_selection(&WidgetDirection::Down),
                 KeyCode::Char('r') => {
-                    if reset_sender.send(ThreadControlEvent::Reset).is_ok() {
+                    if reset_sender.send(CollectionThreadEvent::Reset).is_ok() {
                         app.reset();
                     }
                 }
@@ -241,19 +245,17 @@ pub fn read_config(config_location: Option<&String>) -> error::Result<Option<Pat
 pub fn create_or_get_config(config_path: &Option<PathBuf>) -> error::Result<Config> {
     if let Some(path) = config_path {
         if let Ok(config_string) = fs::read_to_string(path) {
-            // We found a config file!
             Ok(toml_edit::de::from_str(config_string.as_str())?)
         } else {
-            // Config file DNE...
             if let Some(parent_path) = path.parent() {
                 fs::create_dir_all(parent_path)?;
             }
-            // fs::File::create(path)?.write_all(CONFIG_TOP_HEAD.as_bytes())?;
+
             fs::File::create(path)?.write_all(CONFIG_TEXT.as_bytes())?;
             Ok(Config::default())
         }
     } else {
-        // Don't write, the config path was somehow None...
+        // Don't write...
         Ok(Config::default())
     }
 }
@@ -264,10 +266,10 @@ pub fn try_drawing(
 ) -> error::Result<()> {
     if let Err(err) = painter.draw_data(terminal, app) {
         cleanup_terminal(terminal)?;
-        return Err(err);
+        Err(err)
+    } else {
+        Ok(())
     }
-
-    Ok(())
 }
 
 pub fn cleanup_terminal(
@@ -323,7 +325,7 @@ pub fn panic_hook(panic_info: &PanicInfo<'_>) {
     )
     .unwrap();
 
-    // Print stack trace.  Must be done after!
+    // Print stack trace. Must be done after!
     execute!(
         stdout,
         Print(format!(
@@ -342,7 +344,7 @@ pub fn update_data(app: &mut App) {
         FrozenState::Frozen(data) => data,
     };
 
-    for proc in app.proc_state.widget_states.values_mut() {
+    for proc in app.states.proc_state.widget_states.values_mut() {
         if proc.force_update_data {
             proc.ingest_data(data_source);
             proc.force_update_data = false;
@@ -350,23 +352,23 @@ pub fn update_data(app: &mut App) {
     }
 
     // FIXME: Make this CPU force update less terrible.
-    if app.cpu_state.force_update.is_some() {
+    if app.states.cpu_state.force_update.is_some() {
         app.converted_data.ingest_cpu_data(data_source);
         app.converted_data.load_avg_data = data_source.load_avg_harvest;
 
-        app.cpu_state.force_update = None;
+        app.states.cpu_state.force_update = None;
     }
 
     // FIXME: This is a bit of a temp hack to move data over.
     {
         let data = &app.converted_data.cpu_data;
-        for cpu in app.cpu_state.widget_states.values_mut() {
+        for cpu in app.states.cpu_state.widget_states.values_mut() {
             cpu.update_table(data);
         }
     }
     {
         let data = &app.converted_data.temp_data;
-        for temp in app.temp_state.widget_states.values_mut() {
+        for temp in app.states.temp_state.widget_states.values_mut() {
             if temp.force_update_data {
                 temp.ingest_data(data);
                 temp.force_update_data = false;
@@ -375,7 +377,7 @@ pub fn update_data(app: &mut App) {
     }
     {
         let data = &app.converted_data.disk_data;
-        for disk in app.disk_state.widget_states.values_mut() {
+        for disk in app.states.disk_state.widget_states.values_mut() {
             if disk.force_update_data {
                 disk.ingest_data(data);
                 disk.force_update_data = false;
@@ -384,7 +386,7 @@ pub fn update_data(app: &mut App) {
     }
 
     // TODO: [OPT] Prefer reassignment over new vectors?
-    if app.mem_state.force_update.is_some() {
+    if app.states.mem_state.force_update.is_some() {
         app.converted_data.mem_data = convert_mem_data_points(data_source);
         #[cfg(not(target_os = "windows"))]
         {
@@ -400,10 +402,10 @@ pub fn update_data(app: &mut App) {
         {
             app.converted_data.gpu_data = convert_gpu_data(data_source);
         }
-        app.mem_state.force_update = None;
+        app.states.mem_state.force_update = None;
     }
 
-    if app.net_state.force_update.is_some() {
+    if app.states.net_state.force_update.is_some() {
         let (rx, tx) = get_rx_tx_data_points(
             data_source,
             &app.app_config_fields.network_scale_type,
@@ -412,7 +414,7 @@ pub fn update_data(app: &mut App) {
         );
         app.converted_data.network_data_rx = rx;
         app.converted_data.network_data_tx = tx;
-        app.net_state.force_update = None;
+        app.states.net_state.force_update = None;
     }
 }
 
@@ -433,12 +435,12 @@ pub fn create_input_thread(
             if let Ok(poll) = poll(Duration::from_millis(20)) {
                 if poll {
                     if let Ok(event) = read() {
-                        // FIXME: Handle all other event cases.
                         match event {
-                            // TODO: Might want to debounce this in the future, or take into account the actual resize
-                            // values. Maybe we want to keep the current implementation in case the resize event might
-                            // not fire... not sure.
                             Event::Resize(_, _) => {
+                                // TODO: Might want to debounce this in the future, or take into account the actual resize
+                                // values. Maybe we want to keep the current implementation in case the resize event might
+                                // not fire... not sure.
+
                                 if sender.send(BottomEvent::Resize).is_err() {
                                     break;
                                 }
@@ -449,8 +451,7 @@ pub fn create_input_thread(
                                 }
                             }
                             Event::Key(key) if key.kind == KeyEventKind::Press => {
-                                // For now, we only care about keydown events. This may change in the future.
-
+                                // For now, we only care about key down events. This may change in the future.
                                 if sender.send(BottomEvent::KeyInput(key)).is_err() {
                                     break;
                                 }
@@ -472,7 +473,9 @@ pub fn create_input_thread(
                                     }
                                 }
                             },
-                            _ => (),
+                            Event::Key(_) => {}
+                            Event::FocusGained => {}
+                            Event::FocusLost => {}
                         }
                     }
                 }
@@ -482,15 +485,15 @@ pub fn create_input_thread(
 }
 
 pub fn create_collection_thread(
-    sender: Sender<BottomEvent>, control_receiver: Receiver<ThreadControlEvent>,
-    termination_ctrl_lock: Arc<Mutex<bool>>, termination_ctrl_cvar: Arc<Condvar>,
+    sender: Sender<BottomEvent>, control_receiver: Receiver<CollectionThreadEvent>,
+    termination_lock: Arc<Mutex<bool>>, termination_cvar: Arc<Condvar>,
     app_config_fields: &AppConfigFields, filters: DataFilters, used_widget_set: UsedWidgets,
 ) -> JoinHandle<()> {
     let temp_type = app_config_fields.temperature_type;
     let use_current_cpu_total = app_config_fields.use_current_cpu_total;
     let unnormalized_cpu = app_config_fields.unnormalized_cpu;
     let show_average_cpu = app_config_fields.show_average_cpu;
-    let update_rate_in_milliseconds = app_config_fields.update_rate_in_milliseconds;
+    let update_time = app_config_fields.update_rate_in_milliseconds;
 
     thread::spawn(move || {
         let mut data_state = data_harvester::DataCollector::new(filters);
@@ -504,43 +507,27 @@ pub fn create_collection_thread(
         data_state.init();
 
         loop {
-            // Check once at the very top...
-            if let Ok(is_terminated) = termination_ctrl_lock.try_lock() {
-                // We don't block here.
+            // Check once at the very top... don't block though.
+            if let Ok(is_terminated) = termination_lock.try_lock() {
                 if *is_terminated {
                     drop(is_terminated);
                     break;
                 }
             }
 
-            let mut update_time = update_rate_in_milliseconds;
             if let Ok(message) = control_receiver.try_recv() {
                 // trace!("Received message in collection thread: {:?}", message);
                 match message {
-                    ThreadControlEvent::Reset => {
+                    CollectionThreadEvent::Reset => {
                         data_state.data.cleanup();
                     }
-                    ThreadControlEvent::UpdateConfig(app_config_fields) => {
-                        data_state.set_temperature_type(app_config_fields.temperature_type);
-                        data_state
-                            .set_use_current_cpu_total(app_config_fields.use_current_cpu_total);
-                        data_state.set_unnormalized_cpu(unnormalized_cpu);
-                        data_state.set_show_average_cpu(app_config_fields.show_average_cpu);
-                    }
-                    ThreadControlEvent::UpdateUsedWidgets(used_widget_set) => {
-                        data_state.set_data_collection(*used_widget_set);
-                    }
-                    ThreadControlEvent::UpdateUpdateTime(new_time) => {
-                        update_time = new_time;
-                    }
                 }
             }
 
             data_state.update_data();
 
-            // Yet another check to bail if needed...
-            if let Ok(is_terminated) = termination_ctrl_lock.try_lock() {
-                // We don't block here.
+            // Yet another check to bail if needed... do not block!
+            if let Ok(is_terminated) = termination_lock.try_lock() {
                 if *is_terminated {
                     drop(is_terminated);
                     break;
@@ -553,8 +540,9 @@ pub fn create_collection_thread(
                 break;
             }
 
-            if let Ok((is_terminated, _wait_timeout_result)) = termination_ctrl_cvar.wait_timeout(
-                termination_ctrl_lock.lock().unwrap(),
+            // This is actually used as a "sleep" that can be interrupted by another thread.
+            if let Ok((is_terminated, _)) = termination_cvar.wait_timeout(
+                termination_lock.lock().unwrap(),
                 Duration::from_millis(update_time),
             ) {
                 if *is_terminated {
