@@ -11,7 +11,6 @@ use indexmap::IndexSet;
 use layout_options::*;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
-use typed_builder::*;
 
 #[cfg(feature = "battery")]
 use starship_battery::Manager;
@@ -44,7 +43,7 @@ pub struct Config {
     pub processes: Option<ProcessConfig>,
 }
 
-#[derive(Clone, Debug, Default, Deserialize, Serialize, TypedBuilder)]
+#[derive(Clone, Debug, Default, Deserialize, Serialize)]
 pub struct ConfigFlags {
     pub hide_avg_cpu: Option<bool>,
     pub dot_marker: Option<bool>,
@@ -58,8 +57,8 @@ pub struct ConfigFlags {
     pub whole_word: Option<bool>,
     pub regex: Option<bool>,
     pub basic: Option<bool>,
-    pub default_time_value: Option<u64>,
-    pub time_delta: Option<u64>,
+    pub default_time_value: Option<String>,
+    pub time_delta: Option<String>,
     pub autohide_time: Option<bool>,
     pub hide_time: Option<bool>,
     pub default_widget_type: Option<String>,
@@ -429,27 +428,35 @@ pub fn build_app(
     let net_filter =
         get_ignore_list(&config.net_filter).context("Update 'net_filter' in your config file")?;
 
-    Ok(App::builder()
-        .app_config_fields(app_config_fields)
-        .cpu_state(CpuState::init(cpu_state_map))
-        .mem_state(MemState::init(mem_state_map))
-        .net_state(NetState::init(net_state_map))
-        .proc_state(ProcState::init(proc_state_map))
-        .disk_state(DiskState::init(disk_state_map))
-        .temp_state(TempState::init(temp_state_map))
-        .battery_state(BatteryState::init(battery_state_map))
-        .basic_table_widget_state(basic_table_widget_state)
-        .current_widget(widget_map.get(&initial_widget_id).unwrap().clone()) // TODO: [UNWRAP] - many of the unwraps are fine (like this one) but do a once-over and/or switch to expect?
-        .widget_map(widget_map)
-        .used_widgets(used_widgets)
-        .is_expanded(expanded_upon_startup && !use_basic_mode)
-        .filters(DataFilters {
-            disk_filter,
-            mount_filter,
-            temp_filter,
-            net_filter,
-        })
-        .build())
+    let states = AppWidgetStates {
+        cpu_state: CpuState::init(cpu_state_map),
+        mem_state: MemState::init(mem_state_map),
+        net_state: NetState::init(net_state_map),
+        proc_state: ProcState::init(proc_state_map),
+        temp_state: TempState::init(temp_state_map),
+        disk_state: DiskState::init(disk_state_map),
+        battery_state: BatteryState::init(battery_state_map),
+        basic_table_widget_state,
+    };
+
+    let current_widget = widget_map.get(&initial_widget_id).unwrap().clone();
+    let filters = DataFilters {
+        disk_filter,
+        mount_filter,
+        temp_filter,
+        net_filter,
+    };
+    let is_expanded = expanded_upon_startup && !use_basic_mode;
+
+    Ok(App::new(
+        app_config_fields,
+        states,
+        widget_map,
+        current_widget,
+        used_widgets,
+        filters,
+        is_expanded,
+    ))
 }
 
 pub fn get_widget_layout(
@@ -583,20 +590,27 @@ fn get_show_average_cpu(matches: &ArgMatches, config: &Config) -> bool {
     true
 }
 
-/// FIXME: Let this accept human times.
+fn try_parse_ms(s: &str) -> error::Result<u64> {
+    if let Ok(val) = humantime::parse_duration(s) {
+        Ok(val.as_millis().try_into()?)
+    } else if let Ok(val) = s.parse::<u64>() {
+        Ok(val)
+    } else {
+        Err(BottomError::ConfigError(
+            "could not parse as a valid 64-bit unsigned integer or a human time".to_string(),
+        ))
+    }
+}
+
 fn get_default_time_value(
     matches: &ArgMatches, config: &Config, retention_ms: u64,
 ) -> error::Result<u64> {
     let default_time =
         if let Some(default_time_value) = matches.get_one::<String>("default_time_value") {
-            default_time_value.parse::<u64>().map_err(|_| {
-                BottomError::ConfigError(
-                    "could not parse as a valid 64-bit unsigned integer".to_string(),
-                )
-            })?
+            try_parse_ms(default_time_value)?
         } else if let Some(flags) = &config.flags {
-            if let Some(default_time_value) = flags.default_time_value {
-                default_time_value
+            if let Some(default_time_value) = &flags.default_time_value {
+                try_parse_ms(default_time_value)?
             } else {
                 DEFAULT_TIME_MILLISECONDS
             }
@@ -622,14 +636,10 @@ fn get_time_interval(
     matches: &ArgMatches, config: &Config, retention_ms: u64,
 ) -> error::Result<u64> {
     let time_interval = if let Some(time_interval) = matches.get_one::<String>("time_delta") {
-        time_interval.parse::<u64>().map_err(|_| {
-            BottomError::ConfigError(
-                "could not parse as a valid 64-bit unsigned integer".to_string(),
-            )
-        })?
+        try_parse_ms(time_interval)?
     } else if let Some(flags) = &config.flags {
-        if let Some(time_interval) = flags.time_delta {
-            time_interval
+        if let Some(time_interval) = &flags.time_delta {
+            try_parse_ms(time_interval)?
         } else {
             TIME_CHANGE_MILLISECONDS
         }
@@ -870,8 +880,135 @@ fn get_retention_ms(matches: &ArgMatches, config: &Config) -> error::Result<u64>
 mod test {
     use clap::ArgMatches;
 
-    use super::{get_color_scheme, get_widget_layout, Config};
-    use crate::{app::App, canvas::canvas_styling::CanvasStyling};
+    use super::{get_color_scheme, get_time_interval, get_widget_layout, Config};
+    use crate::{
+        app::App,
+        canvas::canvas_styling::CanvasStyling,
+        options::{get_default_time_value, try_parse_ms, ConfigFlags},
+    };
+
+    #[test]
+    fn verify_try_parse_ms() {
+        let a = "100s";
+        let b = "100";
+        let c = "1 min";
+        let d = "1 hour 1 min";
+
+        assert_eq!(try_parse_ms(a), Ok(100 * 1000));
+        assert_eq!(try_parse_ms(b), Ok(100));
+        assert_eq!(try_parse_ms(c), Ok(60 * 1000));
+        assert_eq!(try_parse_ms(d), Ok(3660 * 1000));
+
+        let a_bad = "1 test";
+        let b_bad = "-100";
+
+        assert!(try_parse_ms(a_bad).is_err());
+        assert!(try_parse_ms(b_bad).is_err());
+    }
+
+    #[test]
+    fn matches_human_times() {
+        let config = Config::default();
+        let app = crate::clap::build_app();
+
+        {
+            let app = app.clone();
+            let delta_args = vec!["btm", "--time_delta", "2 min"];
+            let matches = app.get_matches_from(delta_args);
+
+            assert_eq!(
+                get_time_interval(&matches, &config, 60 * 60 * 1000),
+                Ok(2 * 60 * 1000)
+            );
+        }
+
+        {
+            let default_time_args = vec!["btm", "--default_time_value", "300s"];
+            let matches = app.get_matches_from(default_time_args);
+
+            assert_eq!(
+                get_default_time_value(&matches, &config, 60 * 60 * 1000),
+                Ok(5 * 60 * 1000)
+            );
+        }
+    }
+
+    #[test]
+    fn matches_number_times() {
+        let config = Config::default();
+        let app = crate::clap::build_app();
+
+        {
+            let app = app.clone();
+            let delta_args = vec!["btm", "--time_delta", "120000"];
+            let matches = app.get_matches_from(delta_args);
+
+            assert_eq!(
+                get_time_interval(&matches, &config, 60 * 60 * 1000),
+                Ok(2 * 60 * 1000)
+            );
+        }
+
+        {
+            let default_time_args = vec!["btm", "--default_time_value", "300000"];
+            let matches = app.get_matches_from(default_time_args);
+
+            assert_eq!(
+                get_default_time_value(&matches, &config, 60 * 60 * 1000),
+                Ok(5 * 60 * 1000)
+            );
+        }
+    }
+
+    #[test]
+    fn config_human_times() {
+        let app = crate::clap::build_app();
+        let matches = app.get_matches_from(["btm"]);
+
+        let mut config = Config::default();
+        let flags = ConfigFlags {
+            time_delta: Some("2 min".to_string()),
+            default_time_value: Some("300s".to_string()),
+            ..Default::default()
+        };
+
+        config.flags = Some(flags);
+
+        assert_eq!(
+            get_time_interval(&matches, &config, 60 * 60 * 1000),
+            Ok(2 * 60 * 1000)
+        );
+
+        assert_eq!(
+            get_default_time_value(&matches, &config, 60 * 60 * 1000),
+            Ok(5 * 60 * 1000)
+        );
+    }
+
+    #[test]
+    fn config_number_times() {
+        let app = crate::clap::build_app();
+        let matches = app.get_matches_from(["btm"]);
+
+        let mut config = Config::default();
+        let flags = ConfigFlags {
+            time_delta: Some("120000".to_string()),
+            default_time_value: Some("300000".to_string()),
+            ..Default::default()
+        };
+
+        config.flags = Some(flags);
+
+        assert_eq!(
+            get_time_interval(&matches, &config, 60 * 60 * 1000),
+            Ok(2 * 60 * 1000)
+        );
+
+        assert_eq!(
+            get_default_time_value(&matches, &config, 60 * 60 * 1000),
+            Ok(5 * 60 * 1000)
+        );
+    }
 
     fn create_app(mut config: Config, matches: ArgMatches) -> App {
         let (layout, id, ty) = get_widget_layout(&matches, &config).unwrap();
@@ -919,10 +1056,11 @@ mod test {
                 if (default_app.app_config_fields == testing_app.app_config_fields)
                     && default_app.is_expanded == testing_app.is_expanded
                     && default_app
+                        .states
                         .proc_state
                         .widget_states
                         .iter()
-                        .zip(testing_app.proc_state.widget_states.iter())
+                        .zip(testing_app.states.proc_state.widget_states.iter())
                         .all(|(a, b)| (a.1.test_equality(b.1)))
                 {
                     panic!("failed on {arg_name}");
